[Phpmyadmin-git] [SCM] phpMyAdmin branch, master, updated. RELEASE_3_4_5RC1-18997-g4746335

Marc Delisle lem9 at users.sourceforge.net
Tue Sep 13 18:29:00 CEST 2011


The branch, master has been updated
       via  47463352c4941b4db35ead6b954d2b597f11eebb (commit)
      from  c38cf7eacc7e1090573700e6432b893f1c563be2 (commit)


- Log -----------------------------------------------------------------
commit 47463352c4941b4db35ead6b954d2b597f11eebb
Author: Marc Delisle <marc at infomarc.info>
Date:   Tue Sep 13 12:28:29 2011 -0400

    Not field but column

-----------------------------------------------------------------------

Summary of changes:
 libraries/export/sql.php |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/libraries/export/sql.php b/libraries/export/sql.php
index 9df3bf6..988ec46 100644
--- a/libraries/export/sql.php
+++ b/libraries/export/sql.php
@@ -208,7 +208,7 @@ if (isset($plugin_list)) {
             $plugin_list['sql']['options'][] = array(
                 'type' => 'bool',
                 'name' => 'backquotes',
-                'text' => __('Enclose table and field names with backquotes <i>(Protects field and table names formed with special characters or keywords)</i>')
+                'text' => __('Enclose table and column names with backquotes <i>(Protects column and table names formed with special characters or keywords)</i>')
                 );
 
             $plugin_list['sql']['options'][] = array('type' => 'end_group');
@@ -505,7 +505,7 @@ if (isset($plugin_list)) {
             $head .= 'SET FOREIGN_KEY_CHECKS=0;' . $crlf;
         }
 
-        /* We want exported AUTO_INCREMENT fields to have still same value, do this only for recent MySQL exports */
+        /* We want exported AUTO_INCREMENT columns to have still same value, do this only for recent MySQL exports */
         if ((!isset($GLOBALS['sql_compatibility']) || $GLOBALS['sql_compatibility'] == 'NONE')
                 && !PMA_DRIZZLE) {
             $head .= 'SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";' . $crlf;
@@ -764,7 +764,7 @@ if (isset($plugin_list)) {
         }
 
         // Complete table dump,
         // Whether to quote table and fields names or not
         // Drizzle always quotes names
         if (!PMA_DRIZZLE) {
             if ($sql_backquotes) {
@@ -782,7 +782,7 @@ if (isset($plugin_list)) {
         //
         // Note: SHOW CREATE TABLE, at least in MySQL 5.1.23, does not
         // produce a displayable result for the default value of a BIT
         // field, nor does the mysqldump command. See MySQL bug 35796
         $result = PMA_DBI_try_query('SHOW CREATE TABLE ' . PMA_backquote($db) . '.' . PMA_backquote($table));
         // an error can happen, for example the table is crashed
         $tmp_error = PMA_DBI_getError();
@@ -764,7 +764,7 @@ if (isset($plugin_list)) {
 
         // Complete table dump,
-        // Whether to quote table and fields names or not
+        // Whether to quote table and column names or not
         // Drizzle always quotes names
         if (!PMA_DRIZZLE) {
@@ -782,7 +782,7 @@ if (isset($plugin_list)) {
         // Note: SHOW CREATE TABLE, at least in MySQL 5.1.23, does not
         // produce a displayable result for the default value of a BIT
-        // field, nor does the mysqldump command. See MySQL bug 35796
+        // column, nor does the mysqldump command. See MySQL bug 35796
         $result = PMA_DBI_try_query('SHOW CREATE TABLE ' . PMA_backquote($db) . '.' . PMA_backquote($table));
         // an error can happen, for example the table is crashed


hooks/post-receive
-- 
phpMyAdmin




More information about the Git mailing list